@@ -12,19 +12,16 @@ require_once '../../SyL.php';
 /**
  * Np[^̐ݒ
  *
- *  webapp_dir - vWFNgfBNg
- *  app_name   - AvP[V
- *  action_key - ANVp[^̃L[
- *  cache      - LbVgp@i͂ŃLbVgpȂj
- *  cache_dir  - LbVt@CۑfBNg
- *  debug      - fobNtO
+ *  project_dir - vWFNgfBNg
+ *  app_name    - AvP[V
+ *  action_key  - ANVp[^̃L[
+ *  cache       - LbVgp@i͂ŃLbVgpȂj
  */
 $config = array(
-  'webapp_dir'   => SYL_DIR . '/example/examples/webapp',
+  'project_dir'  => SYL_DIR . '/example/examples/webapp',
   'app_name'     => 'example',
   'action_key'   => 'action',
-  'cache'        => false,
-  'debug'        => SYL_LOG_WARN
+  'cache'        => false
 );
 
 $controller =& SyL_Controller::getController($config);
