@@ -1,9 +1,4 @@
 <?php
-/**
- * ե९饹
- */
-SyL_Loader::fw('ActionForm');
-
 /** 
  * ͸ڡʥХǡ˥ץ륯饹
  *
@@ -11,7 +6,7 @@ SyL_Loader::fw('ActionForm');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.1 2007/08/27 14:29:53 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.2 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Example2_Index extends AppAction
@@ -37,12 +32,7 @@ class Example2_Index extends AppAction
     {
         // ե
         // ¥եϡexamples/webapp/lib/Example2Form.php
-        $form =& SyL_ActionForm::factory('Example2Form');
-        // ǡ֥ȥå
-        $form->registerInput($data);
-        // ե๽
-        $form->build();
-
+        $form =& $this->getActionForm($data, 'Example2Form');
         if ($context->isPost()) {
             // ϤΥݥȥХå
             if ($form->validate()) {
