@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.4 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.4 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowDel extends SyL_AdmFlow
@@ -106,7 +106,7 @@ class SyL_AdmFlowDel extends SyL_AdmFlow
             // ȥ󥶥
             $conn->commit();
             // DB³λ
-            $conn->closeConnection();
+            $this->closeDB($conn);
 
             // λ̤إ쥯
             SyL_Response::redirect($this->getUrl('fin') . '?__adm=del');
