@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowFin.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowFin.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowFin.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowFin.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowFin extends SyL_AdmFlow
@@ -82,7 +82,7 @@ class SyL_AdmFlowFin extends SyL_AdmFlow
             SyL_Response::redirect($this->getUrl('lst'));
         }
 
-        switch ($data->get('__adm')) {
+        switch ($data->get('adm_action')) {
         case 'new':
         case 'upd':
         case 'del':
@@ -90,7 +90,7 @@ class SyL_AdmFlowFin extends SyL_AdmFlow
         default:
             SyL_Response::redirect($this->getUrl('lst'));
         }
-        $data->set('adm', $data->get('__adm'));
+        $data->set('adm_action', $data->get('adm_action'));
 
         // ʸϢ
         $data->set('title', $form->getStructConfig('title'));
