@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.5 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.5 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowLst extends SyL_AdmFlow
@@ -67,6 +67,48 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         parent::SyL_AdmFlow();
     }
 
+    /**
+     * ᥽åɼ¹˼¹Ԥ᥽å
+     *
+     * @access public
+     * @param object ǡ֥
+     * @param object ƥȥ֥
+     */
+    function preExecute(&$data, &$context)
+    {
+        // AJAXʸѴ
+        switch ($data->get('adm_ajax')) {
+        case 'import':
+        case 'json':
+            $data->apply('mb_convert_encoding', SYL_ENCODE_INTERNAL, SYL_ENCODE_AJAX);
+            break;
+        }
+        parent::preExecute($data, $context);
+    }
+
+    /**
+     * ᥽åɼ¹Ը˼¹Ԥ᥽å
+     * 
+     * @access public
+     * @param object ǡ֥
+     * @param object ƥȥ֥
+     */
+    function postExecute(&$data, &$context)
+    {
+        parent::postExecute($data, $context);
+
+        switch ($data->get('adm_ajax')) {
+        case 'import':
+            $data->apply('mb_convert_encoding', SYL_ENCODE_AJAX, SYL_ENCODE_INTERNAL);
+            $context->setViewType('js.ajax');
+            break;
+        case 'json':
+            $data->apply('mb_convert_encoding', SYL_ENCODE_AJAX, SYL_ENCODE_INTERNAL);
+            $context->setViewType('json');
+            break;
+        }
+    }
+
     /**
      * ɽե
      *
@@ -76,9 +118,16 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
      */
     function execute(&$data, &$context)
     {
+        // JSݡȻϥ󥹥å
+        if ($data->get('adm_ajax') == 'import') {
+            return;
+        }
+
         // ѥ᡼
         $sort = $data->get('sort');
         $page = $data->get('page');
+        $index = $data->get('adm_list_index'); // AjaxξΤ߻
+
         // ե
         $form =& $this->getForm();
         // ǡ֥ȥå
@@ -119,7 +168,8 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         // ǥեȸɽ
         $search_view = $adm->isDefaultSearchView();
 
-        $conn->closeConnection();
+        // DB³λ
+        $this->closeDB($conn);
 
         // ץ饤ޥꥭ
         $primaries    = $adm->getPrimary(false);
@@ -179,6 +229,9 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         $data->set('enable_del', $adm->isDel());
         // Ȳǽե饰
         $data->set('enable_vew', $adm->isVew());
+
+        // AjaxΤߡϢ󥯥ǥå
+        $data->set('index', $index);
     }
 }
 
