@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.4 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.4 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowNew extends SyL_AdmFlow
@@ -93,26 +93,26 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
         // ǡ֥ȥå
         $form->registerInput($data);
         // ե๽
-        $form->build();
+        $form->build(!$context->isPost());
 
         // ʬ
         if ($context->isPost()) {
             // ؿʤ
-            if ($data->get('__adm_next')) {
+            if ($data->get('adm_action_next')) {
                 // Хǡ¹
                 if ($adm->validate()) {
                     // ǧ̤
                     $form->setReadOnly(true);
                 }
-            } else if ($data->get('__adm_exe')) {
+            } else if ($data->get('adm_action_exe')) {
                 // Хǡ¹
                 if ($adm->validate()) {
                     // Ͽ¹
                     $adm->insert();
                     // λ̤إ쥯
-                    SyL_Response::redirect($this->getUrl('fin') . '?__adm=new');
+                    SyL_Response::redirect($this->getUrl('fin') . '?adm_action=new');
                 }
-            } else if ($data->get('__adm_prev')) {
+            } else if ($data->get('adm_action_prev')) {
                 // ǧ̤
             }
         } else {
@@ -120,7 +120,7 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
         }
 
         // DB³λ
-        $conn->closeConnection();
+        $this->closeDB($conn);
 
         // եǥǡ
         $data->set('form', $form->getResultArray());
