@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowVew extends SyL_AdmFlow
@@ -116,13 +116,15 @@ class SyL_AdmFlowVew extends SyL_AdmFlow
         $key_value = $adm->getKeyQuery();
 
         // DB³λ
-        $conn->closeConnection();
+        $this->closeDB($conn);
 
         // եǥǡ
         $data->set('form', $form->getResultArray());
         // 祭ѥ᡼
         $data->set('key_name',  $key_name);
         $data->set('key_value', $key_value);
+        $data->set('key_array', $adm->getKey());
+
         // ɽѥѥ᡼Ѥ
         $data->set('page', $data->get('page'));
         $data->set('sort', $data->get('sort'));
@@ -143,6 +145,9 @@ class SyL_AdmFlowVew extends SyL_AdmFlow
         $data->set('enable_upd', $adm->isUpd());
         // ǽե饰
         $data->set('enable_del', $adm->isDel());
+
+        // Ϣ
+        $data->set('related_links', $form->getRelatedLinks());
     }
 
 }
