@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.4 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.4 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationLst extends SyL_AdmOperation
@@ -68,8 +68,20 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
             // 
             $conditions = $this->dao->createCondition();
             foreach ($this->form->getValues($alias) as $column => $value) {
-                if (($value != null) && ($value !== '')) {
-                    $conditions->addLike($column, '%' . $this->conn->escapeLike($value) . '%');
+                if (is_array($value)) {
+                    $in = array();
+                    foreach ($value as $tmp) {
+                        if (($tmp !== null) && ($tmp !== '')) {
+                            $in[] = $tmp;
+                        }
+                    }
+                    if (count($in) > 0) {
+                        $conditions->addIn($column, $in);
+                    }
+                } else {
+                    if (($value !== null) && ($value !== '')) {
+                        $conditions->addLike($column, '%' . $this->conn->escapeLike($value) . '%');
+                    }
                 }
             }
             $table->setConditions($conditions);
@@ -116,8 +128,16 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
         // ơ֥륪֥Ⱥ롼
         foreach (array_keys($this->tables) as $alias) {
             foreach ($this->form->getValues($alias) as $column => $value) {
-                if (($value != null) && ($value !== '')) {
-                    $search_parameters[] = $column . '=' . urlencode($value);
+                if (is_array($value)) {
+                    foreach ($value as $tmp) {
+                        if (($tmp !== null) && ($tmp !== '')) {
+                            $search_parameters[] = $column . '[]=' . urlencode($tmp);
+                        }
+                    }
+                } else {
+                    if (($value != null) && ($value !== '')) {
+                        $search_parameters[] = $column . '=' . urlencode($value);
+                    }
                 }
             }
         }
@@ -166,7 +186,8 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
         // ¤ӽɽ̾ѹ
         foreach ($this->form->getListColumns() as $name) {
             $headers[$name] = $headers_tmp[$name];
-            $headers[$name]['name'] = isset($this->form->elements_config[$name]['name']) ? $this->form->elements_config[$name]['name'] : $name;
+            $element_config = $this->form->getConfig($name);
+            $headers[$name]['name'] = $element_config['name'];
         }
         return $headers;
     }
@@ -212,9 +233,9 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
             $keys = array();
             foreach ($primaries as $name) {
                 $column = substr($name, strpos($name, '.')+1);
-                $keys[] = $name .'.' . $values[$column];
+                $keys[$column] = $values[$column];
             }
-            $primary_link_parameters[$i] = implode(',', $keys);
+            $primary_link_parameters[$i] = $this->encodeKey($keys);
         }
         return $primary_link_parameters;
     }
