@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationUpd.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationUpd.php,v 1.4 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationUpd.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationUpd.php,v 1.4 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationUpd extends SyL_AdmOperation
@@ -57,19 +57,26 @@ class SyL_AdmOperationUpd extends SyL_AdmOperation
         $data_sources = $this->form->getDataSources();
         foreach ($data_sources as $name => $data_source) {
             // ơ֥륪֥ȼ
-            $table =& $this->tables[$data_source['alias']];
+            $table = null;
+            if (version_compare(PHP_VERSION, '5.0.0', '>=')) {
+                $table = unserialize(serialize($this->tables[$data_source['alias']]));
+            } else {
+                $table = $this->tables[$data_source['alias']];
+            }
             $table->addColumn($data_source['name']);
             $table->addColumn($data_source['value']);
 
             // ¸options
-            if (!isset($this->form->elements_config[$name]['options'])) {
-                $this->form->elements_config[$name]['options'] = array();
+            $element_config = $this->form->getConfig($name);
+            if (!isset($element_config['options'])) {
+                $element_config['options'] = array();
             }
             foreach ($this->dao->select($table) as $values) {
                 $column_name  = current($values);
                 $column_value = next($values);
-                $this->form->elements_config[$name]['options'][$column_value] = $column_name;
+                $element_config['options'][$column_value] = $column_name;
             }
+            $this->form->addConfig($name, $element_config);
         }
     }
 
