@@ -27,15 +27,15 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlow.php,v 1.4 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlow.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ե९饹
+ * ADMбե९饹
  */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_ActionForm.php';
+require_once 'SyL_AdmActionForm.php';
 /**
  * DB饹
  */
@@ -52,7 +52,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Adm.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlow.php,v 1.4 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlow.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlow extends AppAction
@@ -100,14 +100,16 @@ class SyL_AdmFlow extends AppAction
     }
 
     /**
-     * ե४֥Ȥ
+     * ADMե४֥Ȥ
      *
      * @access public
-     * @return object ե४֥
+     * @return object ADMե४֥
      */
     function &getForm()
     {
-        return SyL_ActionForm::factory($this->classname, '', $this->opp_name);
+        $form =& SyL_AdmActionForm::factory($this->classname);
+        $form->setType($this->opp_name);
+        return $form;
     }
 
     /**
