@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/DB/Dao/SyL_DBDaoTable.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperation
@@ -110,7 +110,13 @@ class SyL_AdmOperation
         $this->conn     =& $conn;
         $this->dao      =& new SyL_DBDao($conn);
         $this->relation = $this->dao->createRelation();
-        $this->keys     = $keys;
+        foreach ($keys as $key) {
+           $key = $this->decodeKey($key);
+           if (!is_array($key)) {
+               trigger_error("[SyL error] Invalid primary parameter", E_USER_ERROR);
+           }
+           $this->keys[] = $key;
+        }
     }
 
     /**
@@ -140,11 +146,23 @@ class SyL_AdmOperation
      * @param object ơ֥륪֥
      * @param string ̾
      */
-    function addTable($table, $alias)
+    function addTable(&$table, $alias)
     {
         // ɽ
         foreach ($this->form->getListColumns($alias) as $column) {
+            // ơ֥륪֥Ȥ˼ɲ
             $table->addColumn($column);
+            // ơ֥Хǡɲ
+            $column_def = $table->getColumn($column);
+            if (isset($column_def['validate'])) {
+                $element_config = $this->form->getConfig($column);
+                if (isset($element_config['validate'])) {
+                    $element_config['validate'] = array_merge($column_def['validate'], $element_config['validate']);
+                } else {
+                    $element_config['validate'] = array();
+                }
+                $this->form->addConfig($column, $element_config);
+            }
         }
         if ($alias && is_string($alias)) {
             // ǥեե饰̵
@@ -170,7 +188,11 @@ class SyL_AdmOperation
         list($column1, $column2) = array_map('trim', explode('=', $columns[0]));
         list($alias1, $columnname1) = explode('.', $column1, 2);
         list($alias2, $columnname2) = explode('.', $column2, 2);
-        $this->relation->addJoin($this->tables[$alias1], $this->tables[$alias2], $operator, $columns);
+        if ($operator == '+') {
+            $this->relation->addLeftJoin($this->tables[$alias1], $this->tables[$alias2], $columns);
+        } else {
+            $this->relation->addInnerJoin($this->tables[$alias1], $this->tables[$alias2], $columns);
+        }
     }
 
     /**
@@ -262,6 +284,42 @@ class SyL_AdmOperation
         return ($enable === null) ? true : (bool)$enable;
     }
 
+    /**
+     * 祭ѥ᡼򥨥󥳡ɤ
+     *
+     * @access protected
+     * @param array 祭ѥ᡼
+     * @return string 󥳡ɸ祭ѥ᡼
+     */
+    function encodeKey($key)
+    {
+        $tmp = array();
+        foreach ($key as $name => $value) {
+            $tmp[] = "{$name}={$value}";
+        }
+        return implode("\t", $tmp);
+    }
+
+    /**
+     * 祭ѥ᡼ǥɤ
+     *
+     * @access protected
+     * @param string 祭ѥ᡼
+     * @return array ǥɸ祭ѥ᡼
+     */
+    function decodeKey($key)
+    {
+        $tmp = array();
+        foreach (explode("\t", $key) as $tmp1) {
+            $tmp2 = explode('=', $tmp1);
+            if (count($tmp2) != 2) {
+                return array();
+            }
+            $tmp[$tmp2[0]] = $tmp2[1];
+        }
+        return $tmp;
+    }
+
     /**
      * 祭ɲä
      *
@@ -272,26 +330,19 @@ class SyL_AdmOperation
      */
     function setConditionKey(&$conditions, $alias)
     {
+        if (count($this->keys) == 0) {
+            return false;
+        }
         $valid = true;
+        $and   = false;
         $primaries = $this->getPrimary(true);
-        foreach ($this->keys as $keys) {
-            $and = false;
-            foreach (explode(',', $keys) as $key) {
-                if (substr_count($key, '.') > 1) {
-                    list($alias_tmp, $column, $value) = explode('.', $key, 3);
-                    if ($alias_tmp == $alias) {
-                        if (array_search("{$alias_tmp}.{$column}", $primaries) === false) {
-                            $valid = false;
-                            break;
-                        }
-                        $conditions->addEqual($column, $value, true, $and);
-                        $and = true;
-                    }
-                } else {
-                    $valid = false;
-                    break;
-                }
+        foreach ($this->keys[0] as $name => $value) {
+            if (array_search("{$alias}.{$name}", $primaries) === false) {
+                $valid = false;
+                break;
             }
+            $conditions->addEqual($name, $value, true, $and);
+            $and = true;
         }
         return $valid;
     }
@@ -306,19 +357,21 @@ class SyL_AdmOperation
     {
         $tables = array();
         $primaries = $this->getPrimary(true);
-
         foreach (array_keys($this->tables) as $alias) {
             // ơ֥륪֥ȼ
             $table =& $this->tables[$alias];
-            // 索֥Ⱥ
-            $conditions = $this->dao->createCondition();
-            // 祭糧å
-            $this->setConditionKey($conditions, $alias);
-            // 索֥ȥå
-            $table->setConditions($conditions);
+            if ($alias == $this->form->getMaintenanceTable()) {
+                // 索֥Ⱥ
+                $conditions = $this->dao->createCondition();
+                // 祭糧å
+                $this->setConditionKey($conditions, $alias);
+                // 索֥ȥå
+                $table->setConditions($conditions);
+            }
             // ơ֥륪֥ȥå
             $tables[$alias] =& $table;
         }
+
         // ɽǡ
         $result = $this->dao->select($tables, $this->relation);
         return (count($result) == 0) ? null : $result[0];
@@ -332,16 +385,7 @@ class SyL_AdmOperation
      */
     function getKey()
     {
-        $keys = array();
-        if (count($this->keys) > 0) {
-            foreach (explode(',', $this->keys[0]) as $key) {
-                if (substr_count($key, '.') > 1) {
-                    list($alias, $column, $value) = explode('.', $key, 3);
-                    $keys[$column] = $value;
-                }
-            }
-        }
-        return $keys;
+        return (count($this->keys) > 0) ? $this->keys[0] : '';
     }
 
     /**
@@ -352,7 +396,7 @@ class SyL_AdmOperation
      */
     function getKeyQuery()
     {
-        return (count($this->keys) > 0) ? $this->keys[0] : '';
+        return (count($this->keys) > 0) ? $this->encodeKey($this->keys[0]) : '';
     }
 
     /**
