@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.23 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.24 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,10 +36,6 @@
  * 󥯥饹
  */
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Action.php';
-/**
- * ץꥱ̥󥯥饹
- */
-require_once SYL_APP_DIR . '/AppAction.php';
 
 /**
  * եɤ߹९饹
@@ -48,7 +44,7 @@ require_once SYL_APP_DIR . '/AppAction.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.23 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.24 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -103,6 +99,9 @@ class SyL_ConfigActions extends SyL_Config
      */
     function parseXml()
     {
+        // ١饹
+        SyL_Loader::lib(SYL_ACTION_BASE_CLASS);
+
         if (SYL_CACHE) {
             // åѤ
             $key = SYL_APP_DIR . $this->context->getActionFile() . $this->context->getActionName();
@@ -132,13 +131,9 @@ class SyL_ConfigActions extends SyL_Config
         // ӥ塼פ򥻥å
         $this->context->setViewType($this->action_cache_value['viewType']);
         // 쥤̾򥻥å
-        $this->context->setLayoutName($this->action_cache_value['layout']);
-        // ޥӥ塼
-        if ($this->action_cache_value['customizedViewFile'] && $this->action_cache_value['customizedViewClass']) {
-            $this->context->setCustomizedView($this->action_cache_value['customizedViewClass'], $this->action_cache_value['customizedViewFile']);
-        }
-
-        if (isset($this->action_cache_value['template'])) {
+        $this->context->setLayoutName($this->action_cache_value['layoutName']);
+        // ǥեȥƥץ졼Ȥ򥻥å
+        if (isset($this->action_cache_value['template']) && $this->action_cache_value['template']) {
             $this->context->setTemplateFile($this->action_cache_value['template']);
         }
     }
@@ -211,10 +206,23 @@ class SyL_ConfigActions extends SyL_Config
 
                 // ե뤬̵硢pre, postΤ߼¹
                 if (!is_file($this->context->getActionDir() . $this->context->getActionFile())) {
-                    $this->config[$pre_name]['file']   = SYL_APP_DIR . '/AppAction.php';
-                    $this->config[$pre_name]['class']  = 'AppAction';
-                    $this->config[$post_name]['file']  = SYL_APP_DIR . '/AppAction.php';
-                    $this->config[$post_name]['class'] = 'AppAction';
+                    $action_path  = '';
+                    $action_class = '';
+                    if (SYL_ACTION_BASE_CLASS) {
+                        $action_path  = SyL_Loader::convertPath(SYL_ACTION_BASE_CLASS);
+                        $action_class = SyL_Loader::convertClass(SYL_ACTION_BASE_CLASS);
+                    }
+                    if (is_file(SYL_APP_LIB_DIR . $action_path)) {
+                        $action_path  = SYL_APP_LIB_DIR . $action_path;
+                    } else if (is_file(SYL_PROJECT_LIB_DIR . $action_path)) {
+                        $action_path = SYL_PROJECT_LIB_DIR . $action_path;
+                    } else {
+                        $action_path = SYL_INCLUDE_DIR . '/framework/SyL_Action.php';
+                    }
+                    $this->config[$pre_name]['file']   = $action_path;
+                    $this->config[$pre_name]['class']  = $action_class;
+                    $this->config[$post_name]['file']  = $action_path;
+                    $this->config[$post_name]['class'] = $action_class;
                 }
 
                 // ٥ȥʥ֥Ⱥ
@@ -222,10 +230,8 @@ class SyL_ConfigActions extends SyL_Config
 
                 // ݡͥȥѥ᡼ʳ
                 $this->action_cache_value = array(
-                    'viewType' => isset($attribute['viewType']) ? $attribute['viewType'] : '', // ӥ塼
-                    'layout'   => isset($attribute['layout'])   ? $attribute['layout']   : '', // 쥤
-                    'customizedViewFile'  => isset($attribute['customizedViewFile'])  ? $attribute['customizedViewFile']  : '', // ޥӥ塼
-                    'customizedViewClass' => isset($attribute['customizedViewClass']) ? $attribute['customizedViewClass'] : ''
+                    'viewType'   => isset($attribute['viewType'])   ? $attribute['viewType']   : '', // ӥ塼
+                    'layoutName' => isset($attribute['layoutName']) ? $attribute['layoutName'] : ''  // 쥤
                 );
 
                 // ǥեȥƥץ졼ȼ
