@@ -1,3 +1,48 @@
+<?php
+/**
+ * -----------------------------------------------------------------------------
+ *
+ * SyL - Web Application Framework for PHP
+ *
+ * PHP version 4 (>= 4.3.x) or 5
+ *
+ * Copyright (C) 2006-2007 k.watanabe
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *
+ * -----------------------------------------------------------------------------
+ * @package   SyL
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
+ * @copyright 2006-2007 k.watanabe
+ * @license   http://www.opensource.org/licenses/lgpl-license.php
+ * @version   CVS: $Id: default_error_web.php,v 1.3 2007/05/27 16:24:29 seasonstream Exp $
+ * @link      http://www.syl.jp/
+ * -----------------------------------------------------------------------------
+ */
+
+/**
+ * ʃG[\t@C
+ *
+ * @package   SyL
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
+ * @copyright 2006-2007 k.watanabe
+ * @license   http://www.opensource.org/licenses/lgpl-license.php
+ * @version   CVS: $Id: default_error_web.php,v 1.3 2007/05/27 16:24:29 seasonstream Exp $
+ * @link      http://www.syl.jp/
+ */
+?>
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <head>
