@@ -41,10 +41,10 @@
  * @version   CVS: $Id:$
  * @link      http://www.syl.jp/
  */
-function SyL_Login(id)
+function SyL_Login(id, url)
 {
   this.id = id;
-  this.url = "<?= $login_url ?>";
+  this.url = url;
   this.username = "<?= $login_username ?>";
   this.password = "<?= $login_password ?>";
   this.hash = <?= $login_hash ?>;
