@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.8 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.9 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_User.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.8 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.9 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Auth
@@ -111,7 +111,8 @@ class SyL_Auth
             $user =& $singleton[$type]->getUser();
             // 桼֥ȤƤʤޤϥ󤷤Ƥʤк
             if (!$user) {
-                $singleton[$type]->setUser(new $classname());
+                $obj =& new $classname();
+                $singleton[$type]->setUser($obj);
             }
         }
         return $singleton[$type];
@@ -159,6 +160,7 @@ class SyL_Auth
      */
     function setUser(&$user)
     {
+        //SyL_Loggers::debug(print_r($user, true));
         return $this->session->set($this->session_name, $user);
     }
 
