@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.23 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.24 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.23 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.24 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -336,7 +336,6 @@ class SyL_Error
         return $this->controller->getErrorLine();
     }
 
-
     /**
      * 󥰤¸
      *
@@ -370,7 +369,7 @@ class SyL_Error
      */
     function sendMail()
     {
-        if (($this->controller->getErrorNo() <= SYL_DEBUG) && SYL_ERROR_MAIL && (SYL_MAIL_ADMIN_ADDRESS != '')) {
+        if (($this->controller->getErrorNo() <= SYL_LOG) && SYL_ERROR_MAIL && SYL_MAIL_ADMIN_ADDRESS) {
             // ռ
             $date = date('Y-m-d H:i:s');
             // С̾
@@ -379,8 +378,8 @@ class SyL_Error
                 $server = isset($_SERVER['SERVER_NAME']) ? $_SERVER['SERVER_NAME'] : '';
             }
 
-            $request_uri = isset($_SERVER['REQUEST_URI'])     ? $_SERVER['REQUEST_URI']     : '';
-            $user_agent  = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '';
+            $request_uri = isset($_SERVER['REQUEST_URI'])         ? $_SERVER['REQUEST_URI']     : '';
+            $user_agent  = isset($_SERVER['HTTP_USER_AGENT'])     ? $_SERVER['HTTP_USER_AGENT'] : '';
             $server_software = isset($_SERVER['SERVER_SOFTWARE']) ? $_SERVER['SERVER_SOFTWARE'] : '';
 
             // ȥ졼դ顼å
