@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.14 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.15 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.14 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.15 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -77,47 +77,51 @@ class SyL_Response
      * @access public
      * @param string 쥯URL
      */
-    function redirect($url, $pathinfo=null)
+    function redirect($url)
     {
         if (!preg_match('/^[a-z]+:\/\/(.+)/i', $url)) {
-            $protocol = '';
-            $server   = '';
-            if (isset($_SERVER['SERVER_PORT']) && (($_SERVER['SERVER_PORT'] == '80') || ($_SERVER['SERVER_PORT'] == '443'))) {
-                $protocol = ($_SERVER['SERVER_PORT'] == '80') ? 'http' : 'https';
+            $protocol = 'http';
+            if (isset($_SERVER['HTTPS'])) {
+                $protocol = 'https';
+            } else if (isset($_SERVER['SERVER_PORT']) && ($_SERVER['SERVER_PORT'] == '443')) {
+                $protocol = 'https';
             }
+
+            $server = '';
             if (isset($_SERVER['HTTP_HOST'])) {
                 $server = $_SERVER['HTTP_HOST'];
             } else if (isset($_SERVER['SERVER_NAME'])) {
                 $server = $_SERVER['SERVER_NAME'];
+                if (isset($_SERVER['SERVER_PORT'])) {
+                    $server .= ':' . $_SERVER['SERVER_PORT'];
+                }
             }
 
             if ($protocol && $server) {
                 if (substr($url, 0, 1) == '/') {
                     $url = "{$protocol}://{$server}{$url}";
                 } else {
-                    if ($pathinfo === null) {
-                        $path = '';
-                        if (($pathinfo === true) || (($pathinfo === null) && (strpos(SYL_ROUTER_RULE, 'pathinfo') !== false))) {
-                            if (isset($_SERVER['PHP_SELF'])) {
-                                $path = dirname($_SERVER['PHP_SELF']);
-                            }
-                        } else {
-                            if (isset($_SERVER["SCRIPT_NAME"])) {
-                                $path = dirname($_SERVER["SCRIPT_NAME"]);
-                            }
+                    $path = '';
+                    if (strpos(SYL_ROUTER_RULE, 'pathinfo') !== false) {
+                        if (isset($_SERVER['PHP_SELF'])) {
+                            $path = $_SERVER['PHP_SELF'];
                         }
-                        if ($path) {
-                            if ($path != '/') {
-                                $path .= '/';
-                            }
-                            $path .= $url;
-                            while (preg_match('/^(.+\/)([^\/]+\/\.\.\/)(.+)$/', $path, $matches)) {
-                                $path = $matches[1] . $matches[3];
-                            }
-                            $path = str_replace('./', '', $path);
-                            $url = "{$protocol}://{$server}{$path}";
+                    } else {
+                        if (isset($_SERVER["SCRIPT_NAME"])) {
+                            $path = $_SERVER["SCRIPT_NAME"];
                         }
                     }
+                    if (($path !== '') && (substr($path, -1) != '/')) {
+                        $path = dirname($path) . '/';
+                    }
+                    if ($path) {
+                        $path .= $url;
+                        while (preg_match('/^(.+\/)([^\/]+\/\.\.\/)(.+)$/', $path, $matches)) {
+                            $path = $matches[1] . $matches[3];
+                        }
+                        $path = str_replace('./', '', $path);
+                        $url = "{$protocol}://{$server}{$path}";
+                    }
                 }
             }
         }
