@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDaoTable
@@ -229,6 +229,19 @@ class SyL_DBDaoTable
         $this->is_defaul_all = (bool)$is_defaul_all;
     }
 
+    /**
+     * 
+     *
+     * @access public
+     * @return array 
+     */
+    function getColumn($name)
+    {
+        // ʸ
+        $name = strtoupper($name);
+        return $this->columns[$name];
+    }
+
     /**
      * 
      *
