@@ -35,7 +35,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.6 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.7 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -56,7 +56,7 @@ require_once 'SyL_DBSqlTableRelations.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.6 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.7 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDao
@@ -243,7 +243,7 @@ class SyL_DBDao
         // Ϣ糧å
         $from = '';
         if (is_object($relation)) {
-            $join = $relation->getJoin();
+            $join = $relation->getJoin($this->conn);
             if ($join) {
                 $from = $join;
             }
