@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.21 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.22 2007/10/15 13:56:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'DB/SyL_DBSchema.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.21 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.22 2007/10/15 13:56:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -181,7 +181,7 @@ class SyL_DB
     function &getConnection($dsn='', $server_encode='')
     {
         if (!$dsn) {
-            if (defined('SYL_DB_DSN')) {
+            if (defined('SYL_DB_DSN') && SYL_DB_DSN) {
                 $dsn = SYL_DB_DSN;
             } else {
                 trigger_error("[SyL error] DSN(connection string) not found", E_USER_ERROR);
