@@ -5,7 +5,7 @@
  * @access    public
  * @package   {PROJECT_NAME}
  * @author    {author}
- * @version   $Id: Table.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   $Id: Table.php,v 1.2 2007/09/29 09:10:39 seasonstream Exp $
  */
 class {TABLE_CLASS_NAME} extends SyL_DBDaoTable
 {
@@ -23,7 +23,20 @@ var $table = '{TABLE_NAME}';
  * @var array
  */
 var $primary = {TABLE_PRIMARY};
-
+/**
+ * ե
+ * 
+ * @access protected
+ * @var array
+ */
+var $uniques = {TABLE_UNIQUES};
+/**
+ * 
+ * 
+ * @access protected
+ * @var array
+ */
+var $foreigns = {TABLE_FOREIGNS};
 /**
  * 
  * 
