@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.2 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.3 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.2 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.3 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateApplication
@@ -66,6 +66,7 @@ class CreateApplication
           'actions'   => 0755,
           'config'    => 0755,
           'lib'       => 0755,
+          'lib/App'   => 0755,
           'templates' => 0755
         );
 
@@ -74,7 +75,8 @@ class CreateApplication
           'defines_app.xml' => 'config/defines.xml',
           'filters.xml'     => 'config/filters.xml',
           'layouts.xml'     => 'config/layouts.xml',
-          'AppAction.php'   => 'AppAction.php'
+          'AppAction.php'   => 'lib/App/Action.php',
+          'AppUser.php'     => 'lib/App/User.php'
         );
 
         foreach ($dirs as $dir => $mode) {
